@@ -16,10 +16,11 @@
 __docformat__ = "reStructuredText"
 
 from zope.authentication.interfaces import IUnauthenticatedPrincipal
-from zope.interface import implements
+from zope.interface import implementer
 from zope.pluggableauth import interfaces
 
 
+@implementer(interfaces.ICredentialsPlugin)
 class NoChallengeCredentialsPlugin(object):
     """A plugin that doesn't challenge if the principal is authenticated.
 
@@ -62,22 +63,22 @@ class NoChallengeCredentialsPlugin(object):
 
     On the other hand, if the user is unauthenticated:
 
-      >>> class Principal(object):
-      ...     implements(IUnauthenticatedPrincipal)
+      >>> @implementer(IUnauthenticatedPrincipal)
+      ... class Principal(object):
+      ...     pass
       >>> request.setPrincipal(Principal())
       >>> IUnauthenticatedPrincipal.providedBy(request.principal)
       True
 
     the plugin challenge will return None:
 
-      >>> print challenger.challenge(request)
+      >>> print(challenger.challenge(request))
       None
 
     signaling the PAU that it should try the next plugin for a challenge. If
     the PAU is configured properly, the user will receive a challenge and be
     allowed to provide different credentials.
     """
-    implements(interfaces.ICredentialsPlugin)
 
     def extractCredentials(self, request):
         return None
